==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkHyperTreeCursor.java <==
// java wrapper for vtkHyperTreeCursor object
//

package vtk;
import vtk.*;

public class vtkHyperTreeCursor extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetTree_2();
  public vtkHyperTree GetTree() {
    long temp = GetTree_2();

    if (temp == 0) return null;
    return (vtkHyperTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetLeafId_3();
  public int GetLeafId()
    { return GetLeafId_3(); }

  private native int GetNodeId_4();
  public int GetNodeId()
    { return GetNodeId_4(); }

  private native boolean IsLeaf_5();
  public boolean IsLeaf()
    { return IsLeaf_5(); }

  private native boolean IsTerminalNode_6();
  public boolean IsTerminalNode()
    { return IsTerminalNode_6(); }

  private native boolean IsRoot_7();
  public boolean IsRoot()
    { return IsRoot_7(); }

  private native int GetCurrentLevel_8();
  public int GetCurrentLevel()
    { return GetCurrentLevel_8(); }

  private native int GetChildIndex_9();
  public int GetChildIndex()
    { return GetChildIndex_9(); }

  private native void ToRoot_10();
  public void ToRoot()
    { ToRoot_10(); }

  private native void ToParent_11();
  public void ToParent()
    { ToParent_11(); }

  private native void ToChild_12(int id0);
  public void ToChild(int id0)
    { ToChild_12(id0); }

  private native void ToSameNode_13(vtkHyperTreeCursor id0);
  public void ToSameNode(vtkHyperTreeCursor id0)
    { ToSameNode_13(id0); }

  private native boolean IsEqual_14(vtkHyperTreeCursor id0);
  public boolean IsEqual(vtkHyperTreeCursor id0)
    { return IsEqual_14(id0); }

  private native long Clone_15();
  public vtkHyperTreeCursor Clone() {
    long temp = Clone_15();

    if (temp == 0) return null;
    return (vtkHyperTreeCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int SameTree_16(vtkHyperTreeCursor id0);
  public int SameTree(vtkHyperTreeCursor id0)
    { return SameTree_16(id0); }

  private native int GetIndex_17(int id0);
  public int GetIndex(int id0)
    { return GetIndex_17(id0); }

  private native int GetNumberOfChildren_18();
  public int GetNumberOfChildren()
    { return GetNumberOfChildren_18(); }

  private native int GetDimension_19();
  public int GetDimension()
    { return GetDimension_19(); }

  private native boolean Found_20();
  public boolean Found()
    { return Found_20(); }

  public vtkHyperTreeCursor() { super(); }

  public vtkHyperTreeCursor(long id) { super(id); }

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkHyperTreeCursor.java <==
// java wrapper for vtkHyperTreeCursor object
//

package vtk;
import vtk.*;

public class vtkHyperTreeCursor extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetTree_2();
  public vtkHyperTree GetTree() {
    long temp = GetTree_2();

    if (temp == 0) return null;
    return (vtkHyperTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetLeafId_3();
  public int GetLeafId()
    { return GetLeafId_3(); }

  private native int GetNodeId_4();
  public int GetNodeId()
    { return GetNodeId_4(); }

  private native boolean IsLeaf_5();
  public boolean IsLeaf()
    { return IsLeaf_5(); }

  private native boolean IsTerminalNode_6();
  public boolean IsTerminalNode()
    { return IsTerminalNode_6(); }

  private native boolean IsRoot_7();
  public boolean IsRoot()
    { return IsRoot_7(); }

  private native int GetCurrentLevel_8();
  public int GetCurrentLevel()
    { return GetCurrentLevel_8(); }

  private native int GetChildIndex_9();
  public int GetChildIndex()
    { return GetChildIndex_9(); }

  private native void ToRoot_10();
  public void ToRoot()
    { ToRoot_10(); }

  private native void ToParent_11();
  public void ToParent()
    { ToParent_11(); }

  private native void ToChild_12(int id0);
  public void ToChild(int id0)
    { ToChild_12(id0); }

  private native void ToSameNode_13(vtkHyperTreeCursor id0);
  public void ToSameNode(vtkHyperTreeCursor id0)
    { ToSameNode_13(id0); }

  private native boolean IsEqual_14(vtkHyperTreeCursor id0);
  public boolean IsEqual(vtkHyperTreeCursor id0)
    { return IsEqual_14(id0); }

  private native long Clone_15();
  public vtkHyperTreeCursor Clone() {
    long temp = Clone_15();

    if (temp == 0) return null;
    return (vtkHyperTreeCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int SameTree_16(vtkHyperTreeCursor id0);
  public int SameTree(vtkHyperTreeCursor id0)
    { return SameTree_16(id0); }

  private native int GetIndex_17(int id0);
  public int GetIndex(int id0)
    { return GetIndex_17(id0); }

  private native int GetNumberOfChildren_18();
  public int GetNumberOfChildren()
    { return GetNumberOfChildren_18(); }

  private native int GetDimension_19();
  public int GetDimension()
    { return GetDimension_19(); }

  private native boolean Found_20();
  public boolean Found()
    { return Found_20(); }

  public vtkHyperTreeCursor() { super(); }

  public vtkHyperTreeCursor(long id) { super(id); }

}
